photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerdelete.h
branchRCL_3
changeset 15 191387a8b767
parent 0 4e91876724a2
--- a/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerdelete.h	Wed Apr 14 15:57:24 2010 +0300
+++ b/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerdelete.h	Tue Apr 27 16:37:53 2010 +0300
@@ -40,18 +40,20 @@
 	{
 public:
     /**
      * Two-phase constructor
      * @param aMediaListProvider object that provides the media list
      * @param aIsContainerList If ETrue, shows "delete container"
      *                         confirmation notes and does not allow
      *                         deleting system items
      *                         If EFalse, shows "delete item" 
      *                         confirmation notes and does not check 
      *                         for system items
      */
 	IMPORT_C static CGlxCommandHandlerDelete* NewL(
-	    MGlxMediaListProvider* aMediaListProvider, TBool aIsContainerList, TBool aHasToolbarItem);
-	    
+			MGlxMediaListProvider* aMediaListProvider, TBool aIsContainerList,
+			TBool aHasToolbarItem, const TDesC& aFileName);
+
 	/** Destructor */
 	IMPORT_C ~CGlxCommandHandlerDelete();
     
@@ -79,7 +81,7 @@
 
 private:
     /** Second phase constructor */
-	void ConstructL(TBool aIsContainerList);
+	void ConstructL(TBool aIsContainerList, const TDesC& aFileName);
 
     /** Constructor */
 	CGlxCommandHandlerDelete(MGlxMediaListProvider* aMediaListProvider, TBool aHasToolbarItem);
@@ -40,18 +40,20 @@
 public:
     /**
-     * Two-phase constructor
-     * @param aMediaListProvider object that provides the media list
-     * @param aIsContainerList If ETrue, shows "delete container"
-     *                         confirmation notes and does not allow
-     *                         deleting system items
-     *                         If EFalse, shows "delete item" 
-     *                         confirmation notes and does not check 
-     *                         for system items
-     */
+	 * Two-phase constructor
+	 * @param aMediaListProvider object that provides the media list
+	 * @param aIsContainerList If ETrue, shows "delete container"
+	 *                         confirmation notes and does not allow
+	 *                         deleting system items
+	 *                         If EFalse, shows "delete item" 
+	 *                         confirmation notes and does not check 
+	 *                         for system items
+	 * @param aFileName resource file
+	 */
 	IMPORT_C static CGlxCommandHandlerDelete* NewL(